Index: lemon/lgf_reader.h
===================================================================
--- lemon/lgf_reader.h	(revision 174)
+++ lemon/lgf_reader.h	(revision 182)
@@ -2071,5 +2071,5 @@
   /// \ingroup lemon_io
   ///
   /// \brief Reader for the content of the \ref lgf-format "LGF" file 
   ///
   /// This class can be used to read the sections, the map names and
@@ -2077,24 +2077,24 @@
   /// that, which type of graph, which maps and which attributes
   /// should be read from a file, but in general tools (like glemon)
   /// the content of an LGF file should be guessed somehow. This class
   /// reads the graph and stores the appropriate information for
   /// reading the graph.
   ///
-  ///\code LgfContent content("graph.lgf"); 
-  /// content.run();
+  ///\code LgfContents contents("graph.lgf"); 
+  /// contents.run();
   ///
   /// // does it contain any node section and arc section
-  /// if (content.nodeSectionNum() == 0 || content.arcSectionNum()) {
+  /// if (contents.nodeSectionNum() == 0 || contents.arcSectionNum()) {
   ///   std::cerr << "Failure, cannot find graph" << std::endl;
   ///   return -1;
   /// }
   /// std::cout << "The name of the default node section : " 
-  ///           << content.nodeSection(0) << std::endl;
+  ///           << contents.nodeSection(0) << std::endl;
   /// std::cout << "The number of the arc maps : " 
-  ///           << content.arcMaps(0).size() << std::endl;
+  ///           << contents.arcMaps(0).size() << std::endl;
   /// std::cout << "The name of second arc map : " 
-  ///           << content.arcMaps(0)[1] << std::endl;
+  ///           << contents.arcMaps(0)[1] << std::endl;
   ///\endcode
-  class LgfContent {    
+  class LgfContents {    
   private:
 
@@ -2122,21 +2122,21 @@
     /// \brief Constructor
     ///
     /// Construct an \e LGF content reader, which reads from the given
     /// input stream.
-    LgfContent(std::istream& is) 
+    LgfContents(std::istream& is) 
       : _is(&is), local_is(false) {}
 
     /// \brief Constructor
     ///
     /// Construct an \e LGF content reader, which reads from the given
     /// file.
-    LgfContent(const std::string& fn) 
+    LgfContents(const std::string& fn) 
       : _is(new std::ifstream(fn.c_str())), local_is(true) {}
 
     /// \brief Constructor
     ///
     /// Construct an \e LGF content reader, which reads from the given
     /// file.
-    LgfContent(const char* fn)
+    LgfContents(const char* fn)
       : _is(new std::ifstream(fn)), local_is(true) {}
 
@@ -2145,5 +2145,5 @@
     /// The copy constructor transfers all data from the other reader,
     /// therefore the copied reader will not be usable more. 
-    LgfContent(LgfContent& other)
+    LgfContents(LgfContents& other)
       : _is(other._is), local_is(other.local_is) {
       
@@ -2164,5 +2164,5 @@
     
     /// \brief Destructor
-    ~LgfContent() {
+    ~LgfContents() {
       if (local_is) delete _is;
     }
@@ -2189,5 +2189,5 @@
     ///
     /// Gives back the node maps for the given section.
-    const std::vector<std::string>& nodeMaps(int i) const {
+    const std::vector<std::string>& nodeMapNames(int i) const {
       return _node_maps[i];
     }
@@ -2195,11 +2195,11 @@
     /// @}
 
-    /// \name Arc sections 
+    /// \name Arc/Edge sections 
     /// @{
 
-    /// \brief Gives back the number of arc sections in the file.
-    ///
-    /// Gives back the number of arc sections in the file.
-    /// \note It is synonim of \c edgeSectionNum().
+    /// \brief Gives back the number of arc/edge sections in the file.
+    ///
+    /// Gives back the number of arc/edge sections in the file.
+    /// \note It is synonym of \c edgeSectionNum().
     int arcSectionNum() const {
       return _edge_sections.size();
@@ -2209,32 +2209,26 @@
     ///
     /// Returns the section name at the given position. 
-    /// \note It is synonim of \c edgeSection().
+    /// \note It is synonym of \c edgeSection().
     const std::string& arcSection(int i) const {
       return _edge_sections[i];
     }
 
-    /// \brief Gives back the arc maps for the given section.
-    ///
-    /// Gives back the arc maps for the given section.
-    /// \note It is synonim of \c edgeMaps().
-    const std::vector<std::string>& arcMaps(int i) const {
+    /// \brief Gives back the arc/edge maps for the given section.
+    ///
+    /// Gives back the arc/edge maps for the given section.
+    /// \note It is synonym of \c edgeMapNames().
+    const std::vector<std::string>& arcMapNames(int i) const {
       return _edge_maps[i];
     }
 
-    /// \brief Returns true when the section type is \c "@arcs".
-    ///
-    /// Returns true when the section type is \c "@arcs", and not "@edges".
-    bool isArcSection(int i) const {
-      return _arc_sections[i];
-    }
-
     /// @}
 
-    /// \name Edge sections   
+    /// \name Synonyms
     /// @{
 
-    /// \brief Gives back the number of edge sections in the file.
-    ///
-    /// Gives back the number of edge sections in the file.
+    /// \brief Gives back the number of arc/edge sections in the file.
+    ///
+    /// Gives back the number of arc/edge sections in the file.
+    /// \note It is synonym of \c arcSectionNum().
     int edgeSectionNum() const {
       return _edge_sections.size();
@@ -2244,4 +2238,5 @@
     ///
     /// Returns the section name at the given position. 
+    /// \note It is synonym of \c arcSection().
     const std::string& edgeSection(int i) const {
       return _edge_sections[i];
@@ -2251,13 +2246,7 @@
     ///
     /// Gives back the edge maps for the given section.
-    const std::vector<std::string>& edgeMaps(int i) const {
+    /// \note It is synonym of \c arcMapNames().
+    const std::vector<std::string>& edgeMapNames(int i) const {
       return _edge_maps[i];
-    }
-
-    /// \brief Returns true when the section type is \c "@edges".
-    ///
-    /// Returns true when the section type is \c "@edges", and not "@arcs".
-    bool isEdgeSection(int i) const {
-      return !_arc_sections[i];
     }
 
@@ -2277,5 +2266,5 @@
     ///
     /// Returns the section name at the given position. 
-    const std::string& attributeSection(int i) const {
+    const std::string& attributeSectionNames(int i) const {
       return _attribute_sections[i];
     }
@@ -2360,5 +2349,5 @@
   public:
 
     /// \name Execution of the content reader    
     /// @{
 
@@ -2071,5 +2071,5 @@
   /// \ingroup lemon_io
   ///
-  /// \brief Reader for the content of the \ref lgf-format "LGF" file 
+  /// \brief Reader for the contents of the \ref lgf-format "LGF" file 
   ///
   /// This class can be used to read the sections, the map names and
@@ -2077,24 +2077,24 @@
   /// that, which type of graph, which maps and which attributes
   /// should be read from a file, but in general tools (like glemon)
-  /// the content of an LGF file should be guessed somehow. This class
+  /// the contents of an LGF file should be guessed somehow. This class
   /// reads the graph and stores the appropriate information for
   /// reading the graph.
@@ -2122,21 +2122,21 @@
     /// \brief Constructor
     ///
-    /// Construct an \e LGF content reader, which reads from the given
+    /// Construct an \e LGF contents reader, which reads from the given
     /// input stream.
@@ -2122,21 +2122,21 @@
     /// \brief Constructor
     ///
-    /// Construct an \e LGF content reader, which reads from the given
+    /// Construct an \e LGF contents reader, which reads from the given
     /// file.
@@ -2122,21 +2122,21 @@
     /// \brief Constructor
     ///
-    /// Construct an \e LGF content reader, which reads from the given
+    /// Construct an \e LGF contents reader, which reads from the given
     /// file.
@@ -2360,5 +2349,5 @@
   public:
 
-    /// \name Execution of the content reader    
+    /// \name Execution of the contents reader    
     /// @{
 
